XTran---Transit modeling
=========================

PyA's `XTran` packages bundles several transit models,
which differ in purpose and implementation.

Transit light-curves
---------------------

.. toctree::
  :maxdepth: 1

  Analytical transit model (Pal 2008) <palTransDoc/palTrans.rst>
  Analytical transit model (Mandel & Agol 2002) <forTrans.rst>
  Chromospheric transit model <limBrightTrans.rst>

Rossiter McLaughlin curves
---------------------------

.. toctree::
  :maxdepth: 1
  
  Analytical Rossiter McLaughlin model (Ohta et al. 2005) <RmcLOhtaDoc/index.rst>